@@ -7,7 +7,7 @@ from requests.packages.urllib3.util.retry import Retry
 from typing import List, Optional, Any, Dict, Callable
 from .app import PaymentUri, KycSample, Event, Payment
 from .app.store import _match
-from ... import offchain
+from ... import offchain, jsonrpc
 import requests, logging, random, string, json, time
 
 
@@ -29,7 +29,7 @@ class RestClient:
         self, balances: Optional[Dict[str, int]] = None, kyc_data: Optional[str] = None
     ) -> "AccountResource":
         account = self.create("/accounts", kyc_data=kyc_data, balances=balances)
-        return AccountResource(client=self, id=account["id"], kyc_data=account["kyc_data"])
+        return AccountResource(client=self, id=account["id"], kyc_data=account.get("kyc_data", None))
 
     def new_soft_match_kyc_data(self) -> str:
         return self.new_kyc_data(sample="soft_match")
@@ -61,7 +61,12 @@ class RestClient:
     def send(self, method: str, path: str, data: Optional[str] = None) -> requests.Response:
         url = "%s/%s" % (self.server_url.rstrip("/"), path.lstrip("/"))
         self.logger.info("%s %s: %s" % (method, path, data))
-        resp = self.session.request(method=method, url=url.lower(), data=data)
+        resp = self.session.request(
+            method=method,
+            url=url.lower(),
+            data=data,
+            headers={"Content-Type": "application/json", "User-Agent": jsonrpc.client.USER_AGENT_HTTP_HEADER},
+        )
         self.logger.info("response status code: %s" % resp.status_code)
         self.logger.info("response body: %s" % resp.text)
         resp.raise_for_status()
@@ -76,7 +81,7 @@ class AccountResource:
     kyc_data: str
 
     def balance(self, currency: str) -> int:
-        return self.balances().get(currency, 0)
+        return self._balances().get(currency, 0)
 
     def send_payment(self, currency: str, amount: int, payee: str) -> Payment:
         p = self.client.create(self._resources("payment"), payee=payee, currency=currency, amount=amount)
@@ -85,9 +90,6 @@ class AccountResource:
     def create_payment_uri(self) -> PaymentUri:
         return PaymentUri(**self.client.create(self._resources("payment_uri")))
 
-    def balances(self) -> Dict[str, int]:
-        return self.client.get(self._resources("balance"))
-
     def events(self, start: int = 0) -> List[Event]:
         ret = self.client.send("GET", self._resources("event")).json()
         return [Event(**obj) for obj in ret[start:]]
@@ -133,5 +135,14 @@ class AccountResource:
     def info(self, *args: Any, **kwargs: Any) -> None:
         self.client.logger.info(*args, **kwargs)
 
+    def _balances(self) -> Dict[str, int]:
+        """returns account balances object
+
+        should always prefer to use func `balance(currency) -> int`, which returns zero
+        when currency not exist in the response.
+        """
+
+        return self.client.get(self._resources("balance"))
+
     def _resources(self, resource: str) -> str:
         return "/accounts/%s/%ss" % (self.id, resource)
